@@ -35,8 +35,13 @@ func ByGroups(emitters ...Emitter) Emitter {
 	return EmitterFunc(func(groups []string, lexer Lexer) Iterator {
 		iterators := make([]Iterator, 0, len(groups)-1)
 		// NOTE: If this panics, there is a mismatch with groups
-		for i, group := range groups[1:] {
-			iterators = append(iterators, emitters[i].Emit([]string{group}, lexer))
+		if len(emitters) != len(groups)-1 {
+			iterators = append(iterators, Error.Emit(groups, lexer))
+			// panic(errors.Errorf("number of groups %q does not match number of emitters %v", groups, emitters))
+		} else {
+			for i, group := range groups[1:] {
+				iterators = append(iterators, emitters[i].Emit([]string{group}, lexer))
+			}
 		}
 		return Concaterator(iterators...)
 	})
@@ -255,7 +260,7 @@ func (l *LexerState) Get(key interface{}) interface{} {
 }
 
 // Iterator returns the next Token from the lexer.
-func (l *LexerState) Iterator() Token {
+func (l *LexerState) Iterator() Token { // nolint: gocognit
 	for l.Pos < len(l.Text) && len(l.Stack) > 0 {
 		// Exhaust the iterator stack, if any.
 		for len(l.iteratorStack) > 0 {
